한국어 튜토리얼 — pygame-ce v2.3.2 documentation

##### pygame-ce documentation

Pygame-ce Home || Help Contents || Reference Index

Most useful stuff: Color | display | draw | event | font | image | key | locals | mixer | mouse | Rect | Surface | time | music | pygame

Advanced stuff: cursors | joystick | mask | sprite | transform | BufferProxy | freetype | gfxdraw | midi | PixelArray | pixelcopy | sndarray | surfarray | math

Other: camera | controller | examples | scrap | system | tests | touch | version

## 한국어 튜토리얼

1 부

  프롤로그/소개

2 부

  텍스트 출력

3 부

  텍스트 이동

4 부

  텍스트 조종

5 부

  HP바

6 부

  버튼들

7 부

  게임판

8 부

  에필로그

Edit on GitHub